# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

sys.path.insert(0, os.path.abspath("../../nmfprofiler/utils"))
sys.path.insert(0, os.path.abspath("../../nmfprofiler"))
sys.path.insert(0, os.path.abspath("../.."))
# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "NMFProfiler"
copyright = "2024, Aurélie Mercadié"
author = "Aurélie Mercadié"
release = "0.3.0"

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    "sphinx.ext.autodoc",
    "sphinx_rtd_theme",
    "myst_parser",
    "sphinx.ext.mathjax",
    "sphinx_multiversion",
]
myst_enable_extensions = ["dollarmath", "amsmath"]
autodoc_mock_imports = [
    "matplotlib",
    "numpy",
    "pandas",
    "sklearn",
    "scikit-learn",
    "seaborn",
    "statsmodels",
]

source_suffix = {
    ".rst": "restructuredtext",
    ".txt": "markdown",
    ".md": "markdown",
}

templates_path = ["_templates"]
exclude_patterns = []

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
html_theme = "sphinx_rtd_theme"
html_static_path = ["_static"]

# for sphinx-multiversions # https://github.com/Holzhaus/sphinx-multiversion
# https://blog.stephane-robert.info/post/sphinx-documentation-multi-version/
smv_tag_whitelist = r'^v\d+(\.\d+)+$'  # tags of form v*.*.x and latest
# Whitelist pattern for branches (set to '' to ignore all branches)
smv_branch_whitelist = r'^dev$'
smv_released_pattern = r'^tags/.*$'
smv_remote_whitelist = r'^.*$'
